==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/webui/webui.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#ifndef WEBUI_H
#define WEBUI_H

#include <QObject>
#include <QPointer>

namespace Http
{
    class Server;
}

namespace Net
{
    class DNSUpdater;
}

class AbstractWebApplication;

class WebUI : public QObject
{
    Q_OBJECT
    Q_DISABLE_COPY(WebUI)

public:
    WebUI();

    bool isErrored() const;

signals:
    void fatalError();

private slots:
    void configure();

private:
    bool m_isErrored;
    QPointer<Http::Server> m_httpServer;
    QPointer<Net::DNSUpdater> m_dnsUpdater;
    QPointer<AbstractWebApplication> m_webapp;
    quint16 m_port;
};

#endif // WEBUI_H

==> qbittorrent_4.4.1.orig.tar.xz: qbittorrent-4.4.1/src/webui/webui.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QObject>
#include <QPointer>

namespace Http
{
    class Server;
}

namespace Net
{
    class DNSUpdater;
}

class WebApplication;

class WebUI : public QObject
{
    Q_OBJECT
    Q_DISABLE_COPY_MOVE(WebUI)

public:
    WebUI();

    bool isErrored() const;

signals:
    void fatalError();

private slots:
    void configure();

private:
    bool m_isErrored;
    QPointer<Http::Server> m_httpServer;
    QPointer<Net::DNSUpdater> m_dnsUpdater;
    QPointer<WebApplication> m_webapp;
    quint16 m_port;
};
